@@ -85,7 +85,7 @@ const Application = new Lang.Class({
         this._initAppMenu();
         application = this;
         settings = new Gio.Settings({ schema: 'org.gnome.gnome-sound-recorder' });
-        this.ensure_directory()
+        this.ensure_directory();
     },
     
     ensure_directory: function() {
@@ -170,7 +170,7 @@ const Application = new Lang.Class({
         aboutDialog.license_type = Gtk.License.GPL_2_0;
         aboutDialog.logo_icon_name = 'gnome-sound-recorder';
         aboutDialog.version = pkg.version;
-        aboutDialog.website = 'http://live.gnome.org/GnomeSoundRecorder';
+        aboutDialog.website = 'https://wiki.gnome.org/Apps/SoundRecorder';
         aboutDialog.wrap_license = true;
         aboutDialog.modal = true;
         aboutDialog.transient_for = this.window;
